@@ -2,13 +2,12 @@
 ;;
 ;; Filename:    nimbus-theme.el
 ;; Description: Nimbus dark theme
-;; Author:      Marcin Swieczkowski <marcin.swieczkowski@gmail.com>
-;;              See README.md for full list of contributors.
+;; Author:      Marcin Swieczkowski <marcin@realemail.net>
 ;; Created:     Thu Mar 2 22:19:19 CET 2017
-;; Package-Version: 1.3.0
-;; Package-Revision: 178557148f2e
+;; Package-Version: 20251201.2205
+;; Package-Revision: fb35c0c89e7d
 ;; Package-Requires: ((emacs "24.1"))
-;; URL:         https://github.com/m-cat/nimbus-theme
+;; URL:         https://github.com/mrcnski/nimbus-theme
 ;; Keywords:    faces
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
@@ -46,7 +45,7 @@
 ;;
 ;;; Code:
 
-(deftheme nimbus "An awesome dark theme.")
+(deftheme nimbus "Beautiful, slightly retro dark theme.")
 
 (let* (
        ;; Define the palette.
@@ -57,14 +56,15 @@
        (dark-green     "#1d9a79")
        (darker-green   "#058945")
        (lighter-blue   "#86b5e8")
-       (light-blue     "#68a5e9")
+       (light-blue     "#70a5e1")
        (blue           "#598bc1")
        (dark-blue      "#267E99")
+       (blue-purple    "#7f7dca")
        (light-orange   "#eaaa0c")
-       (orange         "#df9522")
+       (orange         "#db931f")
        (dark-tan       "#7d7c61")
        (bright-yellow  "#fffe0a")
-       (yellow         "#baba36")
+       (yellow         "#b6b635")
        (pink           "#cd9595")
        (purple         "#ab75c3")
        (brown          "#987654")
@@ -101,32 +101,37 @@
 
        ;; Define color variables.
 
-       (cursor         nimbus-warn)
+       (cursor         bright-yellow)
        (fringe         "#212121")
 
-       (archive        orange)
-       (code           orange)
+       (archive        blue-purple)
+       (checkbox       blue)
+       (code           blue-purple)
        (current        yellow)
        (date           light-blue)
+       (directory      dark-green)
        (executable     red)
        (file           blue)
        (file-suffix    light-gray)
-       (hash           dark-tan)
+       (hash           blue-gray)
        (heading        purple)
        (hl-line        blue-bg)
        (ignore         blue-gray)
-       (indent         darker-gray)
+       (indent         darkest-gray)
        (key            blue)
        (line           blue-gray)
        (line-current   green)
        (name           dark-green)
-       (number         orange)
+       (number         purple)
+       (operator       orange)
+       (property       blue-purple)
        (selection      purple-bg)
        (separator      brown)
        (special        blue-gray)
        (strike         brown)
        (summary        red)
        (tag            dark-blue)
+       (value          green)
 
        (lazy           light-blue)
        (match          light-green)
@@ -173,7 +178,7 @@
 
    ;;; Font lock
 
-   `(font-lock-builtin-face ((t (:foreground ,blue))))
+   `(font-lock-builtin-face ((t (:foreground ,blue-purple))))
    `(font-lock-comment-face ((t (:foreground ,light-gray :slant italic))))
    `(font-lock-comment-delimiter-face ((t (:inherit font-lock-comment-face))))
    `(font-lock-function-name-face ((t (:foreground ,dark-green))))
@@ -211,6 +216,26 @@
    `(aw-background-face ((t (:foreground ,dark-gray))))
    `(aw-leading-char-face ((t (:foreground ,black :background ,dark-green))))
 
+   ;; ansi
+   `(ansi-color-black ((t (:foreground ,bg :background ,bg))))
+   `(ansi-color-blue ((t (:foreground ,blue :background ,blue))))
+   `(ansi-color-cyan ((t (:foreground ,lighter-blue :background ,lighter-blue))))
+   `(ansi-color-green ((t (:foreground ,green :background ,green))))
+   `(ansi-color-magenta ((t (:foreground ,purple :background ,purple))))
+   `(ansi-color-red ((t (:foreground ,red :background ,red))))
+   `(ansi-color-white ((t (:foreground ,fg :background ,fg))))
+   `(ansi-color-yellow ((t (:foreground ,yellow :background ,yellow))))
+
+   ; TODO: Same as non-bright counterparts for now, due to lack of faces.
+   `(ansi-color-bright-black ((t (:foreground ,bg :background ,bg))))
+   `(ansi-color-bright-blue ((t (:foreground ,blue :background ,blue))))
+   `(ansi-color-bright-cyan ((t (:foreground ,lighter-blue :background ,lighter-blue))))
+   `(ansi-color-bright-green ((t (:foreground ,green :background ,green))))
+   `(ansi-color-bright-magenta ((t (:foreground ,purple :background ,purple))))
+   `(ansi-color-bright-red ((t (:foreground ,red :background ,red))))
+   `(ansi-color-bright-white ((t (:foreground ,fg :background ,fg))))
+   `(ansi-color-bright-yellow ((t (:foreground ,yellow :background ,yellow))))
+
    ;; anzu
    `(anzu-match-1 ((t (:inherit isearch))))
    `(anzu-match-2 ((t (:inherit lazy-highlight))))
@@ -260,6 +285,9 @@
    `(avy-lead-face-1 ((t (:inherit avy-lead-face :background ,fg))))
    `(avy-lead-face-2 ((t (:inherit avy-lead-face :background ,match))))
 
+   ;; benchmark-init
+   `(benchmark-init/header-face ((t (:foreground ,heading))))
+
    ;; bm
    `(bm-face ((t (:foreground unspecified :background ,teal-bg))))
    `(bm-fringe-face ((t (:inherit bm-face))))
@@ -306,6 +334,12 @@
    `(compilation-mode-line-run ((t (:inherit compilation-warning))))
    `(compilation-mode-line-fail ((t (:inherit compilation-error))))
 
+   `(consult-file ((t (:foreground ,file))))
+   `(consult-imenu-prefix ((t (:foreground ,line))))
+   `(consult-key ((t (:foreground ,key))))
+   `(consult-line-number ((t (:foreground ,line))))
+   `(consult-projectile-projects ((t (:foreground ,directory))))
+
    ;; custom
    `(custom-button ((t (:inherit button :underline nil :box t))))
    `(custom-button-mouse ((t (:inherit highlight :box t))))
@@ -368,9 +402,10 @@
    `(diff-hl-delete ((t (:inherit fringe :foreground ,diff-removed))))
 
    ;; dired
+   `(dired-directory ((t (:foreground ,directory))))
    `(dired-header ((t (:foreground ,heading))))
    `(dired-flagged ((t (:foreground ,dark-red))))
-   `(dired-symlink ((t (:foreground ,yellow))))
+   `(dired-symlink ((t (:foreground ,yellow :slant italic))))
 
    ;; diredfl
    `(diredfl-compressed-file-name ((t (:foreground ,archive))))
@@ -387,7 +422,7 @@
    `(diredfl-file-suffix ((t (:foreground ,file-suffix))))
    `(diredfl-ignored-file-name ((t (:foreground ,ignore))))
    `(diredfl-number ((t (:foreground ,number))))
-   `(diredfl-symlink ((t (:inherit dired-symlink :slant italic))))
+   `(diredfl-symlink ((t (:inherit dired-symlink))))
 
    `(diredfl-dir-priv ((t (:foreground ,purple))))
    `(diredfl-exec-priv ((t (:foreground ,red))))
@@ -415,7 +450,7 @@
    `(diredp-mode-line-flagged ((t (:inherit dired-flagged))))
    `(diredp-mode-line-marked ((t (:inherit dired-mark))))
    `(diredp-number ((t (:foreground ,number))))
-   `(diredp-symlink ((t (:inherit dired-symlink :slant italic))))
+   `(diredp-symlink ((t (:inherit dired-symlink))))
    `(diredp-tagged-autofile-name ((t (:inherit diredp-autofile-name))))
 
    `(diredp-dir-priv ((t (:foreground ,purple))))
@@ -447,7 +482,7 @@
 
    ;; eglot
    `(eglot-highlight-symbol-face ((t (:inherit highlight))))
-   `(eglot-diagnostic-tag-unnecessary-face ((t (:underline (:color ,nimbus-warn :style wave)))))
+   `(eglot-diagnostic-tag-unnecessary-face ((t (:underline (:color ,blue-gray :style wave)))))
 
    ;; elfeed
    `(elfeed-log-debug-level-face ((t (:foreground ,blue))))
@@ -481,7 +516,7 @@
    `(erc-direct-msg-face ((t (:foreground ,red))))
    `(erc-fool-face ((t (:foreground ,hash))))
    `(erc-input-face ((t (:foreground ,current))))
-   `(erc-keyword-face ((t (:foreground, light-green :bold t))))
+   `(erc-keyword-face ((t (:foreground ,match :bold t))))
    `(erc-my-nick-face ((t (:foreground ,orange))))
    `(erc-nick-default-face ((t (:foreground ,blue))))
    `(erc-nick-msg-face ((t (:inherit erc-direct-msg-face :bold t))))
@@ -495,8 +530,13 @@
    `(eshell-ls-directory ((t (:inherit dired-directory))))
    `(eshell-ls-executable ((t (:foreground ,executable))))
    `(eshell-ls-product ((t (:foreground ,orange))))
+   `(eshell-ls-symlink ((t (:inherit dired-symlink))))
    `(eshell-prompt ((t (:foreground ,heading))))
 
+   ;; eshell-syntax-highlighting
+   `(eshell-syntax-highlighting-alias-face ((t (:inherit dired-symlink :bold t))))
+   `(eshell-syntax-highlighting-option-face ((t (:foreground ,blue-purple))))
+
    ;; evil-search-highlight-persist
    `(evil-search-highlight-persist-highlight-face ((t (:inherit match))))
 
@@ -544,6 +584,11 @@
    `(git-gutter:separator ((t (:foreground ,separator :bold t))))
    `(git-gutter:unchanged ((t (:foreground ,yellow))))
 
+   ;; goggles
+   `(goggles-added ((t (:background ,green-bg))))
+   `(goggles-changed ((t (:background ,purple-bg))))
+   `(goggles-removed ((t (:background ,red-bg))))
+
    ;; gnus
    `(gnus-button ((t (:bold t))))
    `(gnus-emphasis-highlight-words ((t (:foreground ,bright-yellow :background ,black))))
@@ -614,7 +659,7 @@
 
    ;; guide-key
    `(guide-key/prefix-command-face ((t (:foreground ,heading))))
-   `(guide-key/highlight-command-face ((t (:foreground ,dark-green))))
+   `(guide-key/highlight-command-face ((t (:foreground ,value))))
    `(guide-key/key-face ((t (:foreground ,key))))
 
    ;; helm
@@ -660,14 +705,24 @@
    `(helm-swoop-target-line-face ((t (:inherit highlight))))
    `(helm-swoop-target-line-block-face ((t (:inherit helm-swoop-target-line-face :foreground ,white))))
 
+   ;; help
+   `(help-argument-name ((t (:inherit font-lock-variable-name-face))))
+
+   ;; helpful
+   `(helpful-heading ((t (:inherit header-line :bold t :extend t))))
+
+   ;; highlight-changes
+   `(highlight-changes ((t (:underline (:color ,nimbus-success)))))
+   `(highlight-changes-delete ((t (:foreground ,nimbus-err :underline t))))
+
    ;; highlight-indentation
    `(highlight-indentation-current-column-face ((t (:background ,gray))))
    `(highlight-indentation-face ((t (:background ,indent))))
 
    ;; highlight-indent-guides
    `(highlight-indent-guides-character-face ((t (:foreground ,indent))))
-   `(highlight-indent-guides-odd-face ((t (:background ,darkest-gray))))
-   `(highlight-indent-guides-even-face ((t (:background ,darkest-gray))))
+   `(highlight-indent-guides-odd-face ((t (:background ,indent))))
+   `(highlight-indent-guides-even-face ((t (:background ,indent))))
    `(highlight-indent-guides-top-odd-face ((t (:background ,teal-bg))))
    `(highlight-indent-guides-top-even-face ((t (:background ,teal-bg))))
 
@@ -675,7 +730,7 @@
    `(highlight-numbers-number ((t (:foreground ,number))))
 
    ;; highlight-operators
-   `(highlight-operators-face ((t (:foreground ,orange))))
+   `(highlight-operators-face ((t (:foreground ,operator))))
 
    ;; highlight-quoted
    `(highlight-quoted-symbol ((t (:foreground ,purple))))
@@ -687,11 +742,14 @@
    `(highlight-thing ((t (:inherit highlight))))
 
    ;; hl-line
-   `(hl-line ((t (:background ,hl-line))))
+   `(hl-line ((t (:background ,hl-line :extend t))))
 
    ;; hl-todo
    `(hl-todo ((t (:foreground ,pink :bold nil :slant italic))))
 
+   ;; idle-highlight-mode
+   `(idle-highlight ((t (:inherit highlight))))
+
    ;; ido
    `(flx-highlight-face ((t (:foreground ,light-blue :underline nil :bold t))))
    `(ido-only-match ((t (:foreground ,match))))
@@ -780,7 +838,7 @@
    `(magit-branch-local ((t (:foreground ,orange))))
    `(magit-branch-remote ((t (:foreground ,yellow))))
    `(magit-filename ((t (:foreground ,file))))
-   `(magit-hash ((t (:foreground ,blue-gray))))
+   `(magit-hash ((t (:foreground ,hash))))
    `(magit-refname ((t (:foreground ,dark-green))))
    `(magit-section-heading ((t (:foreground ,heading))))
    `(magit-section-heading-selection ((t (:foreground ,red))))
@@ -858,13 +916,17 @@
    `(makefile-space ((t (:inherit trailing-whitespace))))
 
    ;; makey
-   `(makey-key-mode-button-face ((t (:inherit font-lock-constant-face))))
+   `(makey-key-mode-args-face ((t (:foreground ,value))))
+   `(makey-key-mode-button-face ((t (:foreground ,key))))
+   `(makey-key-mode-header-face ((t (:foreground ,heading))))
+   `(makey-key-mode-switch-face ((t (:foreground ,orange))))
 
    ;; Man
    `(Man-overstrike ((t (:foreground ,blue))))
    `(Man-underline ((t (:foreground ,yellow))))
 
    ;; markdown
+   `(markdown-gfm-checkbox-face ((t (:foreground ,checkbox))))
    `(markdown-code-face ((t (:foreground ,code))))
    `(markdown-header-face ((t (:foreground ,heading))))
 
@@ -883,6 +945,9 @@
    ;; minibuffer
    `(minibuffer-prompt ((t (:foreground ,bright-yellow :bold nil))))
 
+   ;; mmv
+   `(mmv-face ((t (:underline ,white))))
+
    ;; mode-line
    `(mode-line ((t (:foreground ,fg :background ,light-purple-bg))))
    `(mode-line-inactive ((t (:foreground ,lighter-gray :background ,gray-bg))))
@@ -920,12 +985,14 @@
    `(nswbuff-separator-face ((t (:foreground ,separator))))
    `(nswbuff-special-buffers-face ((t (:foreground ,special))))
 
-   ;; org
+   ;; org-mode
+   `(org-block ((t (:foreground ,fg))))
    `(org-block-begin-line ((t (:inherit org-meta-line :underline ,indent))))
    `(org-block-end-line ((t (:inherit org-meta-line :overline ,indent))))
-   `(org-checkbox ((t (:foreground ,dark-tan :bold t))))
+   `(org-checkbox ((t (:foreground ,checkbox t))))
    `(org-checkbox-statistics-done ((t (:foreground ,dark-green))))
    `(org-checkbox-statistics-todo ((t (:foreground ,red))))
+   `(org-code ((t (:foreground ,code))))
    `(org-date ((t (:inherit link))))
    `(org-date-selected ((t (:inherit highlight :foreground ,current))))
    `(org-document-info ((t (:foreground ,lighter-green))))
@@ -933,6 +1000,7 @@
    `(org-done ((t (:foreground ,dark-green))))
    `(org-drawer ((t (:foreground ,special))))
    `(org-ellipsis ((t (:foreground ,light-gray))))
+   `(org-footnote ((t (:inherit link))))
    `(org-headline-done ((t (:foreground ,light-gray :strike-through ,strike))))
    `(org-hide ((t (:foreground ,bg))))
    `(org-level-1 ((t (:foreground ,rainbow-1))))
@@ -956,9 +1024,9 @@
    `(org-warning ((t (:inherit font-lock-warning-face :foreground ,red))))
 
    ;; org-agenda
-   `(org-agenda-date ((t (:foreground ,date :bold t))))
+   `(org-agenda-date ((t (:foreground ,light-blue :bold t))))
    `(org-agenda-date-today ((t (:inherit org-agenda-date :box t))))
-   `(org-agenda-date-weekend ((t (:inherit org-agenda-date :underline t))))
+   `(org-agenda-date-weekend ((t (:foreground ,blue))))
    `(org-agenda-done ((t (:inherit org-done))))
    `(org-agenda-structure ((t (:foreground ,heading))))
 
@@ -978,6 +1046,16 @@
    ;; org-super-agenda
    `(org-super-agenda-header ((t (:foreground ,brown))))
 
+   ;; outline-mode
+   `(outline-1 ((t (:inherit org-level-1))))
+   `(outline-2 ((t (:inherit org-level-2))))
+   `(outline-3 ((t (:inherit org-level-3))))
+   `(outline-4 ((t (:inherit org-level-4))))
+   `(outline-5 ((t (:inherit org-level-5))))
+   `(outline-6 ((t (:inherit org-level-6))))
+   `(outline-7 ((t (:inherit org-level-7))))
+   `(outline-8 ((t (:inherit org-level-8))))
+
    ;; package
    `(package-name ((t (:inherit link))))
    `(package-status-available ((t (:foreground ,green))))
@@ -1112,8 +1190,24 @@
    `(term-default-fg-color ((t (:inherit fg))))
 
    ;; transient
+   `(transient-argument ((t (:foreground ,yellow :bold t))))
+   `(transient-disabled-suffix ((t (:background ,red-bg))))
+   `(transient-enabled-suffix ((t (:background ,green-bg))))
    `(transient-heading ((t (:foreground ,heading))))
    `(transient-key ((t (:foreground ,key))))
+   `(transient-key-exit ((t (:foreground ,key))))
+   `(transient-key-return ((t (:foreground ,red))))
+   `(transient-key-stack ((t (:foreground ,blue-purple))))
+   `(transient-key-stay ((t (:foreground ,orange))))
+   `(transient-value ((t (:foreground ,value))))
+
+   ;; tree-sitter
+   `(tree-sitter-hl-face:constant.builtin ((t (:foreground ,number))))
+   `(tree-sitter-hl-face:function.call ((t (:foreground ,dark-green))))
+   `(tree-sitter-hl-face:number ((t (:foreground ,number))))
+   ;; `(tree-sitter-hl-face:operator ((t (:foreground ,operator))))
+   `(tree-sitter-hl-face:operator ((t (:foreground ,fg))))
+   `(tree-sitter-hl-face:property ((t (:foreground ,property))))
 
    ;; twittering
    `(twittering-timeline-footer-face ((t (:foreground ,heading))))
@@ -1128,7 +1222,12 @@
    `(undo-tree-visualizer-current-face ((t (:foreground ,current))))
    `(undo-tree-visualizer-unmodified-face ((t (:foreground ,purple))))
 
+   ;; vline
+   `(vline ((t (:background ,hl-line))))
+   `(vline-visual ((t (:background ,teal-bg))))
+
    ;; vertico
+   `(vertico-group-title ((t (:foreground ,heading))))
    `(vertico-indexed ((t (:foreground ,line))))
    `(vertico-quick1 ((t (:inherit default :foreground ,black :background ,search))))
    `(vertico-quick2 ((t (:inherit vertico-quick1 :background ,lazy))))
@@ -1153,7 +1252,7 @@
    `(web-mode-css-comment-face ((t (:inherit font-lock-comment-face))))
    `(web-mode-css-function-face ((t (:foreground ,blue))))
    `(web-mode-css-priority-face ((t (:foreground ,blue))))
-   `(web-mode-css-property-name-face ((t (:inherit font-lock-variable-name-face))))
+   `(web-mode-css-property-name-face ((t (:foreground ,property))))
    `(web-mode-css-pseudo-class-face ((t (:foreground ,blue))))
    `(web-mode-css-selector-face ((t (:foreground ,blue))))
    `(web-mode-css-string-face ((t (:foreground ,yellow))))
@@ -1200,7 +1299,7 @@
    `(which-key-special-key-face ((t (:foreground ,special))))
    `(which-key-group-description-face ((t (:foreground ,heading))))
    `(which-key-highlighted-command-face ((t (:inherit which-key-command-description-face :underline t))))
-   `(which-key-command-description-face ((t (:foreground ,dark-green))))
+   `(which-key-command-description-face ((t (:foreground ,value))))
    `(which-key-local-map-description-face ((t (:inherit font-lock-variable-name-face))))
 
    ;; whitespace
@@ -1229,6 +1328,7 @@
 
    ) ;; end of custom-theme-set-faces
 
+  ;; NOTE: Obsolete.
   (custom-theme-set-variables
    'nimbus
    `(ansi-color-names-vector
@@ -1241,7 +1341,7 @@
 
 ;;;###autoload
 (defun nimbus-theme()
-  "Apply 'nimbus-theme'."
+  "Apply ‘nimbus-theme’."
   (interactive)
   (load-theme 'nimbus t))
 
